@@ -25,14 +25,14 @@ class CreateOrderForRdsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Drds', '2019-01-23', 'CreateOrderForRds','drds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Params(self):
+	def get_Params(self): # String
 		return self.get_query_params().get('Params')
 
-	def set_Params(self,Params):
-		self.add_query_param('Params',Params)
\ No newline at end of file
+	def set_Params(self, Params):  # String
+		self.add_query_param('Params', Params)
